from ctypes import *
netSNMP = cdll.LoadLibrary( r'c:\bin\net-snmp\bin\netsnmp.dll' )

# oid can actually be either of two specs, c_ulong or c_ubyte (uchar, actually)
# don't yet see how to test for it at run-time
oid = c_ulong

ASN_CONTEXT       = 0x80
ASN_CONSTRUCTOR   = 0x20
MAX_OID_LEN       = 128

SNMP_MSG_GET      = (ASN_CONTEXT | ASN_CONSTRUCTOR | 0x0) # a0=160
SNMP_MSG_GETNEXT  = (ASN_CONTEXT | ASN_CONSTRUCTOR | 0x1) # a1=161
SNMP_MSG_RESPONSE = (ASN_CONTEXT | ASN_CONSTRUCTOR | 0x2) # a2=162 
SNMP_MSG_SET      = (ASN_CONTEXT | ASN_CONSTRUCTOR | 0x3) # a3=163

SNMP_MSG_TRAP     = (ASN_CONTEXT | ASN_CONSTRUCTOR | 0x4) # a4=164 

SNMP_MSG_GETBULK  = (ASN_CONTEXT | ASN_CONSTRUCTOR | 0x5) # a5=165 
SNMP_MSG_INFORM   = (ASN_CONTEXT | ASN_CONSTRUCTOR | 0x6) # a6=166
SNMP_MSG_TRAP2    = (ASN_CONTEXT | ASN_CONSTRUCTOR | 0x7) # a7=167
SNMP_MSG_REPORT   = (ASN_CONTEXT | ASN_CONSTRUCTOR | 0x8) # a8=168

lp_variable_list = POINTER( "variable_list" )

class snmp_pdu( Structure ):
	"""Structure storing an SNMP data-unit"""
	_fields_ = [
		("version",  c_long),
		("command",  c_int),
		("reqid",    c_long),
		("msgid",    c_long),
		("transid",  c_long),
		("sessid",   c_long),
		("errstat",  c_long),
		("errindex", c_long),
		("time",     c_ulong),
		("flags",    c_ulong),
		("securityModel", c_int),
		("securityLevel", c_int),
		("msgParseModel", c_int),
		("transport_data", c_void_p),
		("transport_data_length", c_int),

		("tDomain", POINTER( oid ) ), # actually of type const oid
		("tDomainLen", c_short ), # actually size_t

		("variables", lp_variable_list), # actually an snmp_variable_list *

		("community", c_char_p ), # actually a u_char *
		("community_len", c_short), # actually size_t
		
		("enterprise", POINTER( oid )), # oid *
		("enterprise_length", c_short), # actually size_t

		("trap_type", c_long ),
		("specific_type", c_long),

		("agent_addr", c_char*4 ), # actually unsigned char   agent_addr[4]
	]
net_snmp_pdu = snmp_pdu

class variable_list(Structure):
	_fields_ = [
		("next_variable", lp_variable_list),
		("name", POINTER( oid )), # actually an oid*
		("name_length", c_short), # a size_t
		("type", c_ubyte),
		("val", c_void_p), # a netsnmp_vardata, which is a union of 8 or 9 pointer types
		("val_len", c_short), # size_t
		("name_loc", oid*MAX_OID_LEN),
		("buf", c_ubyte*40),
		("data", c_void_p ),
		("dataFreeHook", c_void_p), # (*dataFreeHook)(void *)
		("index", c_int ),
	]

SetPointerType(lp_variable_list, variable_list)


netSNMP.snmp_pdu_create.restype = snmp_pdu
